@@ -58,7 +58,7 @@ BaptistaPike_exact_conditional_CI_2x2 <- function(n, alpha = 0.05) {
 
   return(
     contingencytables_result(
-      list(lower = L, upper = U, estimate = estimate),
+      list("lower" = L, "upper" = U, "estimate" = estimate),
       printresults
     )
   )
