@@ -32,7 +32,7 @@ Exact_multinomial_test_1xc <- function(n, pi0) {
   }
 
   res <- contingencytables_result(
-    list("P" = P), sprintf("The exact multinomial test: P = %7.5f", P)
+    list("Pvalue" = P), sprintf("The exact multinomial test: P = %7.5f", P)
   )
   return(res)
 }
