@@ -5,13 +5,21 @@
 #' @param n the observed counts (a 1xc vector, where c is the number of categories)
 #' @param alpha the nominal level, e.g. 0.05 for 95# CIs
 #' @param adjustment Scheffe or Bonferroni adjustment ("Scheffe" or "Bonferroni")
-#' @param printresults display results (F = no, T = yes)
 #' @examples
-#' # Genotype counts for SNP rs 6498169 in RA patients
-#' Goodman_Wald_CIs_for_diffs_1xc(n = c(276, 380, 118))
+#' Goodman_Wald_CIs_for_diffs_1xc(n = snp6498169$complete$n)
 #' @export
-#' @return A data frame containing lower, upper and point estimates of the statistic
-Goodman_Wald_CIs_for_diffs_1xc <- function(n, alpha = 0.05, adjustment = "Bonferroni", printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Goodman_Wald_CIs_for_diffs_1xc <- function(n, alpha = 0.05, adjustment = "Bonferroni") {
+  validateArguments(
+    x = mget(ls()),
+    types = list(
+      n = "counts", alpha = "probability",
+      adjustment = c("Bonferroni", "Scheffe")
+    )
+  )
+
   c0 <- length(n)
   N <- sum(n)
 
@@ -25,15 +33,6 @@ Goodman_Wald_CIs_for_diffs_1xc <- function(n, alpha = 0.05, adjustment = "Bonfer
   Scheffe <- qchisq(1 - alpha, c0 - 1)
   Bonferroni <- qchisq(1 - alpha / c0, 1)
 
-  if (printresults) {
-    print(
-      sprintf(
-        "The Goodman Wald simultaneous intervals for differences (%s)",
-        adjustment
-      ),
-      quote = FALSE
-    )
-  }
   k <- 0
   for (i in 1:(c0 - 1)) {
     for (j in (i + 1):c0) {
@@ -52,18 +51,29 @@ Goodman_Wald_CIs_for_diffs_1xc <- function(n, alpha = 0.05, adjustment = "Bonfer
         L[k] <- diffs[k] - term2
         U[k] <- diffs[k] + term2
       }
-      if (printresults) {
-        print(
-          sprintf(
-            "  pi_%i - pi_%i: estimate = %6.4f (%6.4f to %6.4f)",
-            i, j, diffs[k], L[k], U[k]
-          ),
-          quote = FALSE
-        )
-      }
     }
   }
 
-  res <- data.frame(lower = L, upper = U, estimate = diffs)
-  invisible(res)
+  # Output
+  printresults <- function() {
+    cat(
+      "The Goodman Wald simultaneous intervals for differences (",
+      adjustment,
+      ")\n ",
+      sep = ""
+    )
+    k <- 0
+    for (i in 1:(c0 - 1)) {
+      for (j in (i + 1):c0) {
+        k <- k + 1
+        txt <- sprintf(
+          " pi_%i - pi_%i: estimate = %6.4f (%6.4f to %6.4f)\n ",
+          i, j, diffs[k], L[k], U[k]
+        )
+        cat(txt)
+      }
+    }
+  }
+  res <- list("lower" = L, "upper" = U, "estimate" = diffs)
+  return(contingencytables_result(res, printresults))
 }
