@@ -56,7 +56,7 @@ Spearman_correlation_coefficient_rxc_bca <- function(n, nboot = 10000, alpha = 0
 
   return(
     contingencytables_result(
-      list(rho = rho, L = L, U = U),
+      list("rho" = rho, "lower" = L, "upper" = U),
       sprintf("The Spearman correlation w / BCa bootstrap CI: rho = %7.4f (%g%% CI %7.4f to %7.4f)", rho, 100 * (1 - alpha), L, U)
     )
   )
