@@ -2,11 +2,21 @@
 # Generic functions                                        #
 # ======================================================== #
 
+#' @export
+#' @title Calculate the lower limit of a confidence interval
+#' @param ... arguments passed to methods
+#' @note This function has little use to the user, it is exported so that
+#' it can be used by [stats::uniroot()].
 calculate_limit_lower <- function(...) {
   method <- convertFunName2Method()
   UseMethod("calculate_limit_lower", method)
 }
 
+#' @export
+#' @title Calculate the upper limit of a confidence interval
+#' @param ... arguments passed to methods
+#' @note This function has little use to the user, it is exported so that
+#' it can be used by [stats::uniroot()].
 calculate_limit_upper <- function(...) {
   method <- convertFunName2Method()
   UseMethod("calculate_limit_upper", method)
@@ -59,41 +69,35 @@ dispatch_lookup <- data.frame(
 #' @author Waldir Leoncio
 convertFunName2Method <- function() {
   callstack <- gsub(x = as.character(sys.calls()), "\\(.+$", "") # func names
-  findInCallstack <- function(regex) {
-    return(!is.na(match(regex, callstack)))
-  }
   cls_match <- dispatch_lookup[match(callstack, dispatch_lookup[["fn"]]), "cls"]
   cls <- cls_match[!is.na(cls_match)]
-  return(structure(cls, class = cls))
+  class(cls) <- cls
+  return(cls)
 }
 
 # ======================================================== #
 # Methods for Mee                                          #
 # ======================================================== #
 
+#' @export
 calculate_limit_lower.Mee <- function(delta0, n11, n21, n1p, n2p, pi1hat,
                                       pi2hat, alpha, ...) {
   ml.res <- ML_estimates(n11, n21, n1p, n2p, delta0)
   T0 <- score_test_statistic(
     pi1hat, pi2hat, delta0, ml.res$p1hat, ml.res$p2hat, n1p, n2p
   )
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   z <- qnorm(1 - alpha / 2, 0, 1)
   f <- T0 - z
   return(f)
 }
 
+#' @export
 calculate_limit_upper.Mee <- function(delta0, n11, n21, n1p, n2p, pi1hat,
                                       pi2hat, alpha, ...) {
   ml.res <- ML_estimates(n11, n21, n1p, n2p, delta0)
   T0 <- score_test_statistic(
     pi1hat, pi2hat, delta0, ml.res$p1hat, ml.res$p2hat, n1p, n2p
   )
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   z <- qnorm(1 - alpha / 2, 0, 1)
   f <- T0 + z
   return(f)
@@ -124,28 +128,24 @@ score_test_statistic.Mee <- function(pi1hat, pi2hat, delta0, p1hat, p2hat, n1p,
 # Methods for Koopman                                      #
 # ======================================================== #
 
+#' @export
 calculate_limit_lower.Koopman <- function(phi0, n11, n21, n1p, n2p, pi1hat,
                                           pi2hat, alpha, ...) {
   ml.res <- ML_estimates(n11, n21, n1p, n2p, phi0)
   T0 <- score_test_statistic(
     pi1hat, pi2hat, ml.res$p1hat, ml.res$p2hat, n1p, n2p, phi0
   )
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 - qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
 
+#' @export
 calculate_limit_upper.Koopman <- function(phi0, n11, n21, n1p, n2p, pi1hat,
                                           pi2hat, alpha, ...) {
   ml.res <- ML_estimates(n11, n21, n1p, n2p, phi0)
   T0 <- score_test_statistic(
     pi1hat, pi2hat, ml.res$p1hat, ml.res$p2hat, n1p, n2p, phi0
   )
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 + qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
@@ -171,23 +171,19 @@ score_test_statistic.Koopman <- function(pi1hat, pi2hat, p1hat, p2hat, n1p,
 # Methods for Miettinen-Nurminen difference                 #
 # ======================================================== #
 
+#' @export
 calculate_limit_lower.Miettinen_diff <- function(delta0, n11, n21, n1p, n2p, pi1hat, pi2hat, alpha, ...) {
   ml.res <- ML_estimates(n11, n21, n1p, n2p, delta0)
   T0 <- score_test_statistic(pi1hat, pi2hat, delta0, ml.res$p1hat, ml.res$p2hat, n1p, n2p)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   z <- qnorm(1 - alpha / 2, 0, 1)
   f <- T0 - z
   return(f)
 }
 
+#' @export
 calculate_limit_upper.Miettinen_diff <- function(delta0, n11, n21, n1p, n2p, pi1hat, pi2hat, alpha, ...) {
   ml.res <- ML_estimates(n11, n21, n1p, n2p, delta0)
   T0 <- score_test_statistic(pi1hat, pi2hat, delta0, ml.res$p1hat, ml.res$p2hat, n1p, n2p)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   z <- qnorm(1 - alpha / 2, 0, 1)
   f <- T0 + z
   return(f)
@@ -217,20 +213,16 @@ score_test_statistic.Miettinen_diff <- function(pi1hat, pi2hat, delta0, p1hat, p
 # Methods for Miettinen-Nurminen Odds Ratio                 #
 # ======================================================== #
 
+#' @export
 calculate_limit_lower.Miettinen_OR <- function(theta0, n11, n21, n1p, n2p, alpha, ...) {
   T0 <- score_test_statistic(theta0, n11, n21, n1p, n2p)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 - qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
 
+#' @export
 calculate_limit_upper.Miettinen_OR <- function(theta0, n11, n21, n1p, n2p, alpha, ...) {
   T0 <- score_test_statistic(theta0, n11, n21, n1p, n2p)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 + qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
@@ -256,22 +248,18 @@ ML_estimates.Miettinen_OR <- function(theta0, n11, n21, n1p, n2p, ...) {
 # Methods for Miettinen-Nurminen CI ratio                  #
 # ======================================================== #
 
+#' @export
 calculate_limit_lower.Miettinen_ratio <- function(phi0, n11, n21, n1p, n2p, pi1hat, pi2hat, alpha, ...) {
   res <- ML_estimates(n11, n21, n1p, n2p, phi0)
   T0 <- score_test_statistic(pi1hat, pi2hat, res$p1hat, res$p2hat, n1p, n2p, phi0)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 - qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
 
+#' @export
 calculate_limit_upper.Miettinen_ratio <- function(phi0, n11, n21, n1p, n2p, pi1hat, pi2hat, alpha, ...) {
   res <- ML_estimates(n11, n21, n1p, n2p, phi0)
   T0 <- score_test_statistic(pi1hat, pi2hat, res$p1hat, res$p2hat, n1p, n2p, phi0)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 + qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
@@ -296,20 +284,16 @@ score_test_statistic.Miettinen_ratio <- function(pi1hat, pi2hat, p1hat, p2hat, n
 # Methods for the uncorrected asymptotic score             #
 # ======================================================== #
 
+#' @export
 calculate_limit_lower.Uncorrected <- function(theta0, n11, n21, n1p, n2p, alpha, ...) {
   T0 <- score_test_statistic(theta0, n11, n21, n1p, n2p)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 - qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
 
+#' @export
 calculate_limit_upper.Uncorrected <- function(theta0, n11, n21, n1p, n2p, alpha, ...) {
   T0 <- score_test_statistic(theta0, n11, n21, n1p, n2p)
-  if (is.na(T0)) {
-    T0 <- 0
-  }
   f <- T0 + qnorm(1 - alpha / 2, 0, 1)
   return(f)
 }
