@@ -1,10 +1,6 @@
 # This file contains print methods used in this package
 
-my_sprintf <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
-}
-
-my_sprintf_cat <- function(s, ...) {
+cat_sprintf <- function(s, ...) {
   cat(sprintf(s, ...))
 }
 
